parserFwk.pyparsing.RecursiveGrammarException

Package parserFwk :: Module pyparsing :: Class RecursiveGrammarException |
[frames | no frames]

## Type RecursiveGrammarException

       object --+
                |
    BaseException --+
                    |
            Exception --+
                        |
                       RecursiveGrammarException

exception thrown by validate() if the grammar could be improperly recursive

Method Summary
| `__init__(self, parseElementList)`
| `__str__(self)`
Inherited from `Exception`: `__new__` Inherited from `BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Class Variable Summary
Inherited from `BaseException`: `args`, `message`

Generated by Epydoc 2.1 on Sun Oct 07 01:31:52 2007 | http://epydoc.sf.net